' VBS Script by Adisak Pochanayon
' Released under the BSD License (Open Source)

'* Copyright (c) 2007, Adisak Pochanayon
'* All rights reserved.
'*
'* Redistribution and use in source and binary forms, with or without
'* modification, are permitted provided that the following conditions are met:
'*     * Redistributions of source code must retain the above copyright
'*       notice, this list of conditions and the following disclaimer.
'*     * Redistributions in binary form must reproduce the above copyright
'*       notice, this list of conditions and the following disclaimer in the
'*       documentation and/or other materials provided with the distribution.
'*     * Neither the name of the original author nor the
'*       names of its contributors may be used to endorse or promote products
'*       derived from this software without specific prior written permission.
'*
'* THIS SOFTWARE IS PROVIDED BY Adisak Pochanayon ``AS IS'' AND ANY
'* EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
'* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
'* DISCLAIMED. IN NO EVENT SHALL Adisak Pochanayon BE LIABLE FOR ANY
'* DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
'* (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
'* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
'* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
'* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
'* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Option Explicit   ' Force explicit variable declaration.
'On Error Resume Next    ' Enable Error Handling
' Boiler Plate Global Scope with Error Handling

'------------------
    SetupGlobals

    ' Globals for the User Code
    Const TXT_SplitFileTag = "<SplitzFile/>"
    Const TXT_BeginSplitTag = "<SplitzLine>"
    Const TXT_EndSplitTag = "</SplitzLine>"

    Main    ' Run! (Execute the User Code)
'------------------

If Err <> 0 Then
    Dim ErrorString
    ErrorString = ErrorToString
    WScript.Echo ErrorString
    Err.Clear   ' destroy the error and
    'MsgBox ErrorString,vbCritical, "ERROR MESSAGE"
End If

On Error Goto 0         ' Disable Error handling
WScript.Quit            ' Exits

'-----------------------------------------------------------
' Global Scope "Library" Variables can be placed here
    Dim WshShell
    Dim WshFso
    Dim WshSysEnv, WshProcEnv, WshUserEnv, WshVolatileEnv
'-----------------------------------------------------------
' Global Scope "Library" Constants can be placed here
    Const FSO_OpenTextFile_Flags_ForReading     = 1
    Const FSO_OpenTextFile_Flags_ForWriting     = 2
    Const FSO_OpenTextFile_Flags_ForAppending   = 8
'-----------------------------------------------------------
Sub SetupGlobals
    Set WshShell = CreateObject("WScript.Shell")

    ' Create the file system object
    Set WshFso = WScript.CreateObject("Scripting.FileSystemObject")

    ' Setup ENVIRONMENT Objects
    Set WshSysEnv = WshShell.Environment("System")
    Set WshProcEnv = WshShell.Environment("Process")
    Set WshUserEnv = WshShell.Environment("User")
    Set WshVolatileEnv = WshShell.Environment("Volatile")
    ' Note on WshVolatileEnv:
    '    This doesn't work: WshVolatileEnv.Remove "ZZZ"
    '    Use this instead:  WshVolatileEnv("ZZZ")=""

End Sub
'-----------------------------------------------------------
Sub ParseCmdLineAndEchoArgs
    Dim arrArgs()
    Dim i,p
    If Wscript.Arguments.Count = 0 Then
        'arrArgs=Array(".")
        Redim arrArgs(0)
        arrArgs(0)="."
    Else
        Redim Preserve arrArgs(Wscript.Arguments.Count - 1)
        For i = 0 to Wscript.Arguments.Count - 1
            arrArgs(i) = Wscript.Arguments(i)
        Next
    End If
    For Each p In arrArgs
        WScript.echo "Arg :" & p
    Next
End Sub
'-----------------------------------------------------------
Function ErrorToString
    Dim ErrorString
    ErrorString = ""
    If Err <> 0 Then
        ErrorString = "An Error Occurred:" & vbNewLine & _
            vbTab & "Number: " & Err.Number & vbNewLine & _
            vbTab & "Description: " & Err.Description & vbNewLine & _
            vbTab & "Source: " & Err.Source & vbNewLine & _
            vbTab & "Help Context ID: " & Err.HelpContext & vbNewLine & _
            vbTab & "Help File: " & Err.HelpFile
    End If
    ErrorToString = ErrorString
End Function
'-----------------------------------------------------------
Function GetEnvVar(EnvName)
    Dim value
    value=WshProcEnv(EnvName)
    If "" = value Then
        value=WshVolatileEnv(EnvName)
        If "" = value Then
            value=WshUserEnv(EnvName)
            If "" = value Then
                value=WshSysEnv(EnvName)
            End If
        End If
    End If
    GetEnvVar = value
End Function
Sub SetEnvVar(EnvName,Value)
    ' Notes on SetEnvVar:
    '   We use WshProcEnv because it can be used
    '     from child and *.BAT files (%var% expansion).
    '   Modifying WshUserEnv and WshSysEnv lead to
    '     permanent env. changes on the system.
    '   Modifying WshVolatileEnv can affect unrelated
    '     applications later on until reboot.
    WshProcEnv(EnvName)=Value
End Sub
Function ExpandEnvStrings(StringToExpand)
    ' Works for "Process" Environment
    ExpandEnvStrings = WshShell.ExpandEnvironmentStrings(StringToExpand)
End Function
'-----------------------------------------------------------
' This is a function to write a string into the registry
Sub WriteRegistryKey_String ( KeyName, StringToWrite )
    WshShell.RegWrite KeyName,StringToWrite,"REG_SZ"
End Sub
' This is a function to read a string from the registry
Function ReadRegistryKey_String ( KeyName )
    Dim StringFromKey
    On Error Resume Next	' User Error Handling for RegRead
    StringFromKey = WshShell.RegRead( KeyName )
    If Err > 0 Then
        StringFromKey = ""
    End If
    ReadRegistryKey_String = StringFromKey
End Function
'-----------------------------------------------------------
Sub ParseArguments
    Dim Args, ArgList, i
    Set Args = WScript.Arguments
    For i =0 to Args.Count - 1
       ArgList = ArgList &i &":"&Args(i) & chr(13)
    Next
    MsgBox "No. of arguments: " & Args.Count & _
        vbNewLine & ArgList
End Sub ' ParseArguments
'-----------------------------------------------------------
Function IE_GetClipText ( )
    ' Note: the IE_GetClipText function does not work
    ' seamlessly with IE7 or later since IE7 has "protection"
    ' against the script system grabbing the clipboard
    ' which pops up a dialog-box for the user to enable
    ' clipboard access.
    Dim objIE
    Set objIE = CreateObject("InternetExplorer.Application")
    objIE.Navigate("about:blank")
    GetClipText = objIE.document.parentwindow. _
        clipboardData.GetData("text")
    objIE.Quit
End Function
Sub IE_PutClipText ( StringToPutInClipboard )
    ' Note: the IE_PutClipText function does not work
    ' seamlessly with IE7 or later since IE7 has "protection"
    ' against the script system grabbing the clipboard
    ' which pops up a dialog-box for the user to enable
    ' clipboard access.
    Dim objIE
    Set objIE = CreateObject("InternetExplorer.Application")
    objIE.Navigate("about:blank")
    objIE.document.parentwindow.clipboardData.SetData _
        "text", StringToPutInClipboard
    objIE.Quit
End Sub
Function HTML_GetClipText ( )
    ' Works Perfectly
    Dim objHTML
    Dim objClipBoard
    Set objHTML = CreateObject("htmlfile")
    Set objClipBoard = objHTML.ParentWindow.ClipboardData
    HTML_GetClipText = objClipBoard.GetData("text")
End Function
Sub HTML_PutClipText ( StringToPutInClipboard )
    ' Note: the HTML_PutClipText function does not work for some reason :(
    Dim objHTML
    Dim objClipBoard
    Set objHTML = CreateObject("htmlfile")
    Set objClipBoard = objHTML.ParentWindow.ClipboardData
    clipboardData.SetData "text", StringToPutInClipboard
End Sub
' Generic versions using best available option
Function GetClipText ( )
    GetClipText = HTML_GetClipText 
End Function
Sub PutClipText ( StringToPutInClipboard )
    IE_PutClipText StringToPutInClipboard
End Sub
'-----------------------------------------------------------
Sub OpenIEatURL (TheURL)
    WshShell.Run "iexplore.exe " & TheURL
End Sub
'-----------------------------------------------------------
Function FormatIntegerToString(Number)
' This function formats a large integer with commas so it will look nice
    FormatIntegerToString = FormatNumber(Number,0,,,-1)
End Function
'-----------------------------------------------------------

'-----------------------------------------------------------
'-----------------------------------------------------------
'-----------------------------------------------------------
'== QuickSort was taken from
' http://4guysfromrolla.com/webtech/012799-2.shtml

Sub QuickSort(ByRef vec,ByVal loBound,ByVal hiBound)
    Dim pivot,loSwap,hiSwap,temp

    '== This procedure is adapted from the algorithm given in:
    '==    Data Abstractions & Structures using C++ by
    '==    Mark Headington and David Riley, pg. 586
    '== Quicksort is the fastest array sorting routine for
    '== unordered arrays.  Its big O is  n log n

    If hiBound <= loBound Then
        Exit Sub
    End If

    '== Two items to sort
    If hiBound - loBound = 1 Then
        if vec(loBound) > vec(hiBound) Then
            temp=vec(loBound)
            vec(loBound) = vec(hiBound)
            vec(hiBound) = temp
        End If
    End If

    '== Three or more items to sort
    pivot = vec(int((loBound + hiBound) / 2))
    vec(int((loBound + hiBound) / 2)) = vec(loBound)
    vec(loBound) = pivot
    loSwap = loBound + 1
    hiSwap = hiBound

    do
        '== Find the right loSwap
        while loSwap < hiSwap and vec(loSwap) <= pivot
            loSwap = loSwap + 1
        wend
        '== Find the right hiSwap
        while vec(hiSwap) > pivot
            hiSwap = hiSwap - 1
        wend
        '== Swap values if loSwap is less then hiSwap
        if loSwap < hiSwap then
            temp = vec(loSwap)
            vec(loSwap) = vec(hiSwap)
            vec(hiSwap) = temp
        End If
    loop while loSwap < hiSwap

    vec(loBound) = vec(hiSwap)
    vec(hiSwap) = pivot

    '== Recursively call function .. the beauty of Quicksort
    '== 2 or more items in first section
    if loBound < (hiSwap - 1) then Call QuickSort(vec,loBound,hiSwap-1)
    '== 2 or more items in second section
    if hiSwap + 1 < hibound then Call QuickSort(vec,hiSwap+1,hiBound)

End Sub  'QuickSort
'-----------------------------------------------------------
'-----------------------------------------------------------
'-----------------------------------------------------------

'-----------------------------------------------------------
' !!!! Begin User Code For Program !!!!
'-----------------------------------------------------------
Function MySafeSplit1 (inputstring,delimit)
    'On Error Resume Next
    Dim strarr
    MySafeSplit1=inputstring
    ' Split-Count must be (N+1) where N is desired number of splits.
    ' A count of 1 will not split the string so 2 is the minimum to be useful.
    strarr=Split(inputstring,delimit,2)
    If UBound(strarr)<=0 Then
        Exit Function
    End If
    MySafeSplit1=strarr(0)
End Function

Function GetFirstWordInLine (linestring)
    Dim workstring
    GetFirstWordInLine=""
    workstring=Replace(linestring,vbTab," ")

    workstring=LTrim(workstring)
    ' workstring=LCase(workstring)
    workstring=MySafeSplit1(workstring," ")
    workstring=MySafeSplit1(workstring,"=")
    workstring=MySafeSplit1(workstring,";")
    GetFirstWordInLine=workstring
End Function

Function CharsToSkipAtBeginning (ByRef instring, ByRef IgnoreCharsAtBeginning)
    Dim offset,found,currchar,testchar,slen
    offset=1
    slen=Len(instring)
    found = True
    Do While found And offset<slen
        found=False
        currchar = Mid(instring,offset,1)
        For Each testchar in IgnoreCharsAtBeginning
            If testchar=currchar Then
                found=True
                offset = offset + 1
                Exit For
            End If
        Next
    Loop
    CharsToSkipAtBeginning = offset
End Function

Function SplitToString (ByRef RetString,ByVal LineBuffer,ByRef FirstWord, _
    ByRef ForceFirstSplitOffset,ByRef PreSplitSeparators,ByRef PostSplitSeparators, _
    ByRef SkipCharsBegin, ByRef KeepCharsAtEnd, ByRef QuoteMarkers)

    Dim StartPos,FoundPos,TempLine
    Dim SepString,TempPos,EndPos
    Dim RetLines
    Dim SplitWithinQuote,EndQuote

    StartPos=InStr(LineBuffer,FirstWord)
    If (StartPos<1) Then
        ' Early exit from function if string is empty
        RetString=LineBuffer & VbCr
        SplitToString=1
        Exit Function
    End If

    ' Normal string split processing
    RetString=""
    RetLines=0
    If (ForceFirstSplitOffset<0) Then
        ' No forced split
        StartPos=StartPos + Len(FirstWord)
    Else
        ' Do forced split at beginning
        FoundPos=StartPos + Len(FirstWord) - 1 + ForceFirstSplitOffset
        EndPos=Len(LineBuffer)
        If (FoundPos>=EndPos) Then
            RetString=RetString & LineBuffer & VbCr
            SplitToString=RetLines+1
            Exit Function
        End If
        TempLine = Left(LineBuffer,FoundPos)
        RetString=RetString & TempLine & VbCr
        RetLines=RetLines+1
        LineBuffer = Right(LineBuffer,EndPos-FoundPos)
        ' Reset to start of string!
        StartPos = CharsToSkipAtBeginning(LineBuffer,SkipCharsBegin)
    End If

    ' Find the rest of the splits by separator and output them
    Do
        EndPos=Len(LineBuffer)
        SplitWithinQuote=False
        Do
            FoundPos=EndPos
            ' Find the Post-Splits
            For Each SepString In PostSplitSeparators
                If Len(SepString) > 0 Then
                    TempPos = InStr(StartPos,LineBuffer,SepString)
                    If (TempPos>0) Then
                        TempPos = TempPos + Len(SepString) - 1  ' After Separator
                        If FoundPos > TempPos Then
                            FoundPos = TempPos
                        End If
                    End If
                End If
            Next
            ' Find the Pre-Splits
            If (StartPos<2) Then
                StartPos=2      ' Never "pre-split" before first character
            End If
            For Each SepString In PreSplitSeparators
                If Len(SepString) > 0 Then
                    TempPos = InStr(StartPos,LineBuffer,SepString)
                    If (TempPos>0) Then
                        TempPos = TempPos - 1 ' Before Separator
                        If FoundPos > TempPos Then
                            FoundPos = TempPos
                        End If
                    End If
                End If
            Next
            ' Check for a Split within Quote markers
            ' We have to restart after the Quotes if that's the case
            If FoundPos<>EndPos And False=SplitWithinQuote Then
                For Each SepString In QuoteMarkers
                    If Len(SepString) > 0 Then
                        TempPos = StartPos-Len(SepString)
                        If TempPos<1 Then
                            TempPos=1
                        End If
                        TempPos = InStr(TempPos,LineBuffer,SepString)
                        If TempPos<>0 And TempPos<FoundPos Then
                            TempPos = InStr(TempPos+Len(SepString),LineBuffer,SepString)
                            If TempPos<>0 Then
                                StartPos = TempPos + Len(SepString)
                                SplitWithinQuote=True
                            End If
                        End If
                    End If
                Next
            Else
                SplitWithinQuote=False
            End If
        Loop While SplitWithinQuote

        ' Keep trailing chars that fit the patterns provided
        Dim found,testchar,currchar
        found=True
        Do While found And FoundPos<EndPos
            found=False
            currchar = Mid(LineBuffer,FoundPos+1,1)
            For Each testchar in KeepCharsAtEnd
                If testchar=currchar Then
                    found=True
                    FoundPos = FoundPos + 1
                    Exit For
                End If
            Next
        Loop

        ' Split the line
        TempLine = Left(LineBuffer,FoundPos)
        RetString=RetString & TempLine & VbCr
        RetLines=RetLines+1
        LineBuffer = Right(LineBuffer,EndPos-FoundPos)
        ' Reset to start of string!
        StartPos = CharsToSkipAtBeginning(LineBuffer,SkipCharsBegin)
    Loop While EndPos <> FoundPos

    If Len(LineBuffer) > 0 Then
        ' Possibly a line left ?
        RetString=RetString & LineBuffer & VbCr
        RetLines=RetLines+1
    End If
    SplitToString=RetLines
End Function

Sub SplitToFile (ByRef OutputFile,ByVal LineBuffer,ByRef FirstWord, _
    ByRef ForceFirstSplitOffset,ByRef PreSplitSeparators,ByRef PostSplitSeparators, _
    ByRef SkipCharsBegin, ByRef KeepCharsAtEnd, ByRef QuoteMarkers)

    Dim SplitStrings,LinesOut

    LinesOut= SplitToString(SplitStrings, LineBuffer, FirstWord, _
        ForceFirstSplitOffset, PreSplitSeparators, PostSplitSeparators, _
        SkipCharsBegin, KeepCharsAtEnd, QuoteMarkers)
    If vbCr <> vbNewLine Then
        SplitStrings=Replace(SplitStrings,vbCr,vbNewLine)
    End If
    If LinesOut>1 Then
        OutputFile.WriteLine(TXT_BeginSplitTag)
        OutputFile.Write(SplitStrings)
        OutputFile.WriteLine(TXT_EndSplitTag)
    Else
        OutputFile.Write(SplitStrings)
    End If
End Sub

Sub SplitSortedToFile (ByRef OutputFile,ByVal LineBuffer,ByRef FirstWord, _
    ByRef ForceFirstSplitOffset,ByRef PreSplitSeparators,ByRef PostSplitSeparators, _
    ByRef SkipCharsBegin, ByRef KeepCharsAtEnd, ByRef QuoteMarkers)

    Dim SplitStrings,LinesOut
    Dim SortedArray

    LinesOut= SplitToString(SplitStrings, LineBuffer, FirstWord, _
        ForceFirstSplitOffset, PreSplitSeparators, PostSplitSeparators, _
        SkipCharsBegin, KeepCharsAtEnd, QuoteMarkers)
    If LinesOut>1 Then
        OutputFile.WriteLine(TXT_BeginSplitTag)

        SplitStrings=Left(SplitStrings,Len(SplitStrings)-1) ' Trim the last vbCr
        SortedArray=Split(SplitStrings, vbCr, -1, 1)

        ' Sort but Skip First & Last Line while sorting
        Call QuickSort(SortedArray,1,(LinesOut-1) -1)

        For Each SplitStrings in SortedArray
            OutputFile.WriteLine(SplitStrings)
        Next

        OutputFile.WriteLine(TXT_EndSplitTag)
    Else
        If vbCr <> vbNewLine Then
            SplitStrings=Replace(SplitStrings,vbCr,vbNewLine)
        End If
        OutputFile.Write(SplitStrings)
    End If
End Sub

Sub Main

    Dim InputFile,InputFilename
    Dim OutputFile,OutputFilename
    Dim LineBuffer,FirstWord
    Dim DoneJoin,TempLine
    Dim PreSplitSeparators,PostSplitSeparators
    Dim SkipCharsBegin,KeepCharsAtEnd
    Dim QuoteMarkers

    If Wscript.Arguments.Count < 2 Then
        Exit Sub
    End If
    InputFilename=Wscript.Arguments(0)
    OutputFilename=Wscript.Arguments(1)
    If (InputFilename = "") Or (OutputFilename = "") Then
        Exit Sub
    End If

    ' Open the files
    Set InputFile = WshFso.OpenTextFile(InputFilename, FSO_OpenTextFile_Flags_ForReading)
    Set OutputFile = WshFso.CreateTextFile(OutputFilename, FSO_OpenTextFile_Flags_ForWriting)

    ' Read first line and check for split or join
    LineBuffer=InputFile.ReadLine
    If LineBuffer = TXT_SplitFileTag Then
        ' Joining File
        Do While (False=InputFile.AtEndOfStream)
            LineBuffer=InputFile.ReadLine
            If TXT_BeginSplitTag <> LineBuffer Then
                OutputFile.WriteLine LineBuffer
            Else
                DoneJoin=False
                LineBuffer=""
                Do
                    TempLine=InputFile.ReadLine
                    If TXT_EndSplitTag <> TempLine Then
                        LineBuffer = LineBuffer & TempLine
                        DoneJoin=InputFile.AtEndOfStream
                    Else
                        DoneJoin=True
                    End If
                Loop While Not DoneJoin
                OutputFile.WriteLine LineBuffer
            End If
        Loop
    Else
        ' Splitting File
        OutputFile.WriteLine TXT_SplitFileTag

        ' VBScript doesn't have a seek-to-beginning so we have to
        ' Close and Re-Open the TextStream to reset the start position
        InputFile.Close
        Set InputFile = WshFso.OpenTextFile(InputFilename, FSO_OpenTextFile_Flags_ForReading)

        ' Set up some constant patterns
        KeepCharsAtEnd = Array(vbTab," ")
        QuoteMarkers = Array("&quot;")

        Do While (False=InputFile.AtEndOfStream)
            LineBuffer=InputFile.ReadLine
            FirstWord=GetFirstWordInLine(LineBuffer)
            Select Case FirstWord

                Case "AdditionalDependencies"
                    ' Line looks like this:
                    ' AdditionalDependencies="a.lib b.lib [...] c.lib"
                    PreSplitSeparators=Array("""") ' More Choices: """","&"
                    PostSplitSeparators=Array(" ") ' More Choices " ",";"
                    SkipCharsBegin=Array(vbTab," ")
                    SplitToFile OutputFile,LineBuffer,FirstWord, _
                        2,PreSplitSeparators,PostSplitSeparators, _
                        SkipCharsBegin,KeepCharsAtEnd,QuoteMarkers

                Case "AdditionalOptions"
                    ' Line looks like one of the following:
                    ' AdditionalOptions="-opta -optb"
                    ' AdditionalOptions="opta;optb"
                    PreSplitSeparators=Array("""") ' More Choices: """","-","&"
                    PostSplitSeparators=Array(" ",";") ' More Choices " ",";"
                    SkipCharsBegin=Array(vbTab," ","-")
                    SplitToFile OutputFile,LineBuffer,FirstWord, _
                        2,PreSplitSeparators,PostSplitSeparators, _
                        SkipCharsBegin,KeepCharsAtEnd,QuoteMarkers

                Case "AdditionalLibraryDirectories"
                    ' Line looks like this:
                    ' AdditionalLibraryDirectories="dir;dir;[...];dir"
                    PreSplitSeparators=Array("""") ' More Choices: """","&"
                    PostSplitSeparators=Array(";")
                    SkipCharsBegin=Array(vbTab," ")
                    SplitToFile OutputFile,LineBuffer,FirstWord, _
                        2,PreSplitSeparators,PostSplitSeparators, _
                        SkipCharsBegin,KeepCharsAtEnd,QuoteMarkers

                Case "AdditionalIncludeDirectories"
                    ' Line looks like this:
                    ' AdditionalIncludeDirectories="dir;dir;[...];dir"
                    PreSplitSeparators=Array("""") ' More Choices: """","&"
                    PostSplitSeparators=Array(";")
                    SkipCharsBegin=Array(vbTab," ")
                    SplitToFile OutputFile,LineBuffer,FirstWord, _
                        2,PreSplitSeparators,PostSplitSeparators, _
                        SkipCharsBegin,KeepCharsAtEnd,QuoteMarkers

                Case "PreprocessorDefinitions"
                    ' Line looks like this:
                    ' PreprocessorDefinitions="DEFINE_1=XXX;DEFINE_2;[...];DEFINE_N=XXX"
                    PreSplitSeparators=Array("""") ' More Choices: """","&"
                    PostSplitSeparators=Array(";")
                    SkipCharsBegin=Array(vbTab," ")
                    SplitToFile OutputFile,LineBuffer,FirstWord, _
                        2,PreSplitSeparators,PostSplitSeparators, _
                        SkipCharsBegin,KeepCharsAtEnd,QuoteMarkers

                Case Else
                    OutputFile.WriteLine LineBuffer
            End Select
        Loop
    End If
End Sub
